@@ -8,29 +8,11 @@ import six
 if six.PY3:
     xrange = range
 
-class RowIterator(six.Iterator):
-    """
-    Iterator over row proxies.
-    """
-    def __init__(self, table):
-        self._table = table
-        self._i = 0
-
-    def __next__(self):
-        try:
-            self._table._data[self._i]
-        except IndexError:
-            raise StopIteration
-        
-        row = self._table._get_row(self._i)
-
-        self._i += 1
-
-        return row
-
 class RowSequence(Sequence):
     """
     Proxy access to rows by index.
+
+    :param table: The :class:`.Table` that contains the rows. 
     """
     def __init__(self, table):
         self._table = table
@@ -55,43 +37,35 @@ class RowSequence(Sequence):
     def __len__(self):
         return len(self._table._data)
 
-class CellIterator(six.Iterator):
-    """
-    Iterator over row cells.
-    """
-    def __init__(self, row):
-        self._row = row
-        self._i = 0
-
-    def __next__(self):
-        try:
-            v = self._row._table._data[self._row._i][self._i]
-        except IndexError:
-            raise StopIteration
-        
-        self._i += 1
-
-        return v 
-
 class Row(Mapping):
     """
     Proxy to row data.
+
+    Values within a row can be accessed by column name or
+    column index.
+
+    :param table: The :class:`Table` that contains this row.
+    :param i: The index of this row in the :class:`Table`.
     """
     def __init__(self, table, i):
         self._table = table
         self._i = i
 
-    def __repr__(self):
+    def __unicode__(self):
         data = self._table._data[self._i]
 
-        sample = repr(data[:5])
+        sample = ', '.join(six.text_type(d) for d in data[:5])
 
         if len(data) > 5:
-            last = sample[-1]
-            sample = sample[:-1] + ', ...' + last
+            sample = '%s, ...' % sample
+
+        sample = '(%s)' % sample
 
         return '<journalism.rows.Row: %s>' % sample 
 
+    def __str__(self):
+        return str(self.__unicode__())
+
     def __getitem__(self, k):
         if isinstance(k, int):
             try:
@@ -114,3 +88,46 @@ class Row(Mapping):
 
     def __eq__(self, other):
         return self._table._data[self._i] == other
+
+class RowIterator(six.Iterator):
+    """
+    Iterator over row proxies.
+
+    :param table: The :class:`.Table` of which to iterate.
+    """
+    def __init__(self, table):
+        self._table = table
+        self._i = 0
+
+    def __next__(self):
+        try:
+            self._table._data[self._i]
+        except IndexError:
+            raise StopIteration
+        
+        row = self._table._get_row(self._i)
+
+        self._i += 1
+
+        return row
+
+class CellIterator(six.Iterator):
+    """
+    Iterator over row cells.
+
+    :param row: The class:`Row` over which to iterate.
+    """
+    def __init__(self, row):
+        self._row = row
+        self._i = 0
+
+    def __next__(self):
+        try:
+            v = self._row._table._data[self._row._i][self._i]
+        except IndexError:
+            raise StopIteration
+        
+        self._i += 1
+
+        return v 
+
